#roloFlash 2

! ***************************************************************************
! *
! *  Beispiel-Skript fuer Microchip/Atmel-ISP-Controller
! *   
! *  Aufgabe: Chip loeschen, danach flashen
! *
! *  Copyright (C) 2009-2018 by halec embedded solutions
! *
! ***************************************************************************


! Fuer alle Dateien auf der SD-Karte gilt:
!  - Dateiname muss im 8.3-Format sein
!  - Dateiname muss komplett in GROSSBUCHSTABEN sein
!  - (siehe Handbuch, Kapitel "Dateien")


! *** Bitte an eigene Beduerfnisse anpassen! ***


targetName      = "STM32F103RB"  ! Exakter Namen aus Handbuch, Kapitel
                                 ! "Spezifikation", uebernehmen
flashFile       = "FLASH.HEX"    ! "" angeben, wenn nicht benoetigt
busSpeed        = 100000         ! Bus-Geschwindigkeit in Hertz. 100 kHz sind
                                 ! eine konservative Wahl, um eine sichere
                                 ! Funktion auch bei niedrigem Target-CPU-Takt
                                 ! oder niedrigem roloFlash-CPU-Takt zu
                                 ! gewaehrleisten. Bei bekanntermassen
                                 ! hoeherem Target-CPU-Takt kann die Bus-
                                 ! Geschwindigkeit entsprechend erhoeht werden.
roloFlashHiSpeedMode = 0         ! 0 (false): circa 20mA@3.3V, ist langsamer
                                 ! 1 (true):  circa 80mA@3.3V, ist schneller

! Gruenes Lauflicht von LED 1 zu LED 4 -> symbolisiert Skript-Abarbeitung
! (Datenbertragungs-Richtung: schreibend)
! (LED 5 wird freigehalten fuer "Fertig"-Anzeige)
ledRunningLight 1, 4, COLOR_GREEN, 200


! ---- Vorbereitungen ----
! Evtl. altes Log loeschen
f = "LOG.TXT"
if fsFileExists(0,f)
  fsRemove 0, f
endif

! Software-Version des roloFlash und Skript-Namen in LOG.TXT schreiben
print "softwareVersion=", softwareVersion, "\r\n"
print "Running script copied from scripts/STM/STM32F1-F4/JTAG/erase-and-flash/ ...\r\n"

! Falls roloFlashHiSpeedMode gewaehlt wurde, dann CPU-Takt des roloFlash auf
! Maximum setzen
if roloFlashHiSpeedMode
  setCpuClock CPU_CLOCKMAX
endif


! ---- Zugriff auf die im roloFlash befindliche Target-Datenbank  ----
dbHandle = DB_getHandle(targetName)

! ---- JTAG-Bus scannen ----
print "Scanning JTAG ...\r\n"
busHandle = JTAG_open(0, busSpeed)
devices = JTAG_scan(busHandle)
print "number of devices:", size(devices), "\r\n"
for i = 0 to size(devices)-1
  print "  Found device: id=", devices[i], "\r\n"
next

! ---- Wenn kein JTAG-device gefunden wurde, dann Abbruch ---
if size(devices) < 2
  print "wrong number of JTAG-device found:", size(devices)
  throw USEREXCEPTION + 1
endif



! ---- Zugriff auf Target ----
print "Connecting to target ...\r\n"
family       = DB_get(dbHandle, DB_FAMILY)
targetHandle = getTargetHandle(busHandle, 0, family)
setTargetMode targetHandle, PROGRAMMODE

  
! ---- Device IDs pruefen ----
print "Checking Device Ids ...\r\n"
expectedCoreIDCODE = DB_get(dbHandle, db_coreIDCODE) and $0fffffff
print "expectedCoreIDCODE", expectedCoreIDCODE, "\r\n"
expectedBoundaryScanIDCODE = DB_get(dbHandle, db_boundaryScanIDCODE) and $0fffffff
print "expectedBoundaryScanIDCODE", expectedBoundaryScanIDCODE, "\r\n"
if ((devices[index] and $0fffffff) <> expectedCoreIDCODE) or (((devices[index+1]) and $0fffffff) <> expectedBoundaryScanIDCODE)
  print "ERROR: Wrong controller detected\r\n"
  ! Abbruch
  throw USEREXCEPTION + 2
endif  


! ---- Target loeschen ----
print "Erasing flash ...\r\n"
eraseFlash targetHandle 


! ---- Target-Flash schreiben ----
if flashFile <> ""
  print "Programming flash file ", flashFile, " ...\r\n"
  writeFileToTarget targetHandle, 0, flashFile, HEX, FLASH, WRITEVERIFY
else
  print "Flash programming skipped (no flash file specified)\r\n"
endif  


! ---- Nachbereitungen ----
closeTarget targetHandle
closeBus busHandle

! do a reset to start the target software  
print "Reseting target ...\r\n"
handle = GPIO_open(GPIO_RST, PIN_PUSHPULL, 0)
delay 100
closeBus handle

! ---- Nach eventuell aufgetretener Exception schauen,         ----
! ---- Auswertung ins Log schreiben und per LEDs signalisieren ----
catch exception
print "Duration [ms]: ", getSystemTime(), "\r\n"
catch dummyException  ! Falls das letzte print eine Exception werfen sollte
if exception <> 0
  ! Es gab einen Fehler, diesen in LOG.TXT festhalten
  print "ERROR: Exception ", exception
  ! Nachdem die Exception mittels catch gefangen wurde, erneut setzen. Damit
  ! wird die Nummer der Exception ueber die LEDs durch Blinkcode angezeigt. Zu
  ! den Blinkcodes siehe Handbuch, Kapitel "Bedeutungen von LED-Codes",
  ! Unterkapitel "Exception aufgetreten".
  throw exception
else
  ! Fehlerfrei: ins Log schreiben und LED 5 auf gruen schalten
  print "Script ended successfully.\r\n"
  ledOn 5, COLOR_GREEN
endif

